@@ -50,6 +50,7 @@
 package com.openexchange.mobile.api.facade.services;
 
 import java.util.Collections;
+import java.util.HashSet;
 import java.util.List;
 
 import com.openexchange.mobile.api.facade.auth.SessionData;
@@ -88,11 +89,26 @@ import lombok.extern.slf4j.Slf4j;
 @Slf4j
 public class FoldersService {
 
+    private static final HashSet<String> ERROR_CODES_AUTHENTICATION = new HashSet<String>();
+
     private final ConnectorFactoryFactory connectorFactoryFactory;
 
     @Setter
     private AccountsService accountsService;
 
+    static {
+        ERROR_CODES_AUTHENTICATION.add("MSG-0091");
+        ERROR_CODES_AUTHENTICATION.add("MSG-0114");
+        ERROR_CODES_AUTHENTICATION.add("MSG-1000");
+        ERROR_CODES_AUTHENTICATION.add("MSG-1001");
+        ERROR_CODES_AUTHENTICATION.add("MSG-1031");
+        ERROR_CODES_AUTHENTICATION.add("OAUTH-0013");
+        ERROR_CODES_AUTHENTICATION.add("OAUTH-0042");
+        ERROR_CODES_AUTHENTICATION.add("OAUTH-0043");
+        ERROR_CODES_AUTHENTICATION.add("OAUTH-0044");
+        ERROR_CODES_AUTHENTICATION.add("pop3-2071");
+    }
+
     public CreatedFolder createFolder(SessionData sessionData, String parentFolderId, String name) {
         ConnectorFactory connectorFactory = connectorFactoryFactory.getConnectorFactory();
         CreateFolderConnector connector = connectorFactory.getCreateFolderConnector(sessionData, parentFolderId, name);
@@ -177,6 +193,7 @@ public class FoldersService {
     }
 
     private List<Folder> retrieveFolders(ConnectorFactory connectorFactory, SessionData sessionData, String rootFolderId, String archiveFolderId, String language) {
+        int userId = getUserId(sessionData);
         boolean includeNonPrivateFolders = sessionData.getConfiguration().isIncludeNonPrivateFolders();
         AllFoldersConnector connector = connectorFactory.getAllFoldersConnector(sessionData, rootFolderId, language);
         FoldersMto data;
@@ -184,16 +201,30 @@ public class FoldersService {
             FoldersResponseMto response = connector.execute();
             data = response.getData();
         } catch (ApiFacadeException e) {
-            log.info("Retrieve folders failed with code: " + e.getErrorCode());
+            String errorCode = e.getErrorCode();
+            log.info("Retrieve folders failed with code: " + errorCode);
+            // OMFACADE-633: Throw authentication errors directly back to the clients.
+            if (ERROR_CODES_AUTHENTICATION.contains(errorCode)) {
+                throw e;
+            }
             // Return fake INBOX folder to not crash older iOS clients.
             Folder inboxFolder = new Folder(rootFolderId + "/INBOX", rootFolderId, "INBOX", Type.INBOX);
             return Collections.singletonList(inboxFolder);
         }
         return data != null
-                ? AllFoldersConnector.map(data.getPrivateFolders(), archiveFolderId, includeNonPrivateFolders)
+                ? AllFoldersConnector.map(data.getPrivateFolders(), archiveFolderId, includeNonPrivateFolders, userId)
                 : Collections.<Folder>emptyList();
     }
 
+    private int getUserId(SessionData sessionData) {
+        try {
+            String userId = sessionData.getProperty(SessionData.PROPERTY_USER_ID);
+            return Integer.valueOf(userId).intValue();
+        } catch (NumberFormatException e) {
+            return -1;
+        }
+    }
+
     /*private*/ void examineFolders(ConnectorFactory connectorFactory, SessionData sessionData, List<Folder> folders) {
         ExamineMultipleFoldersConnector connector = connectorFactory.getExamineMultipleFoldersConnector(sessionData, folders);
         List<ExamineResponseMto> responses = connector.execute();
