@@ -73,7 +73,7 @@ public class WeakforceService {
         String passwordHash = WeakforceUtil.generatePasswordHash(configuration, credentials);
         String deviceId = credentials.getUserAgent();
         String protocol = credentials.getForwardedProto();
-        LTAttrs attributes = createAttributes(credentials);
+        LTAttrs attributes = new LTAttrs();
         return new LoginTupleAllow(credentials.getUsername(), passwordHash, credentials.getRemoteIp(), deviceId, Protocol.HTTP, Protocol.isTls(protocol), attributes);
     }
 
@@ -90,13 +90,8 @@ public class WeakforceService {
         String passwordHash = WeakforceUtil.generatePasswordHash(configuration, credentials);
         String deviceId = credentials.getUserAgent();
         String protocol = credentials.getForwardedProto();
-        LTAttrs attributes = createAttributes(credentials);
+        LTAttrs attributes = new LTAttrs();
         return new LoginTupleReport(credentials.getUsername(), passwordHash, credentials.getRemoteIp(), deviceId, Protocol.HTTP, Protocol.isTls(protocol), loginSuccessful, policyReject, attributes);
     }
 
-    private LTAttrs createAttributes(LoginCredentials credentials) {
-        LTAttrs attributes = new LTAttrs();
-        return attributes;
-    }
-
 }
